@@ -3,7 +3,7 @@ package Padre::Plugin::Moose::Method;
 use namespace::clean;
 use Moose;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 extends 'Padre::Plugin::Moose::ClassMember';
 
@@ -67,7 +67,7 @@ sub get_grid_data {
 	require Wx;
 	return [
 		{ name => Wx::gettext('Name:') },
-		{ name => Wx::gettext('Modifier:') },
+		{ name => Wx::gettext('Modifier:'), choices => [qw(around after before)] },
 	];
 }
 
