@@ -3,7 +3,7 @@ package Padre::Plugin::Moose::Role::HasClassMembers;
 use Moose::Role;
 use namespace::clean;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 has 'attributes' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
 has 'subtypes'   => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
@@ -11,6 +11,7 @@ has 'methods'    => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
 
 sub to_class_members_code {
 	my $self     = shift;
+	my $use_mouse = shift;
 	my $comments = shift;
 
 	my $code = '';
@@ -18,7 +19,7 @@ sub to_class_members_code {
 	# Generate attributes
 	$code .= "\n" if scalar @{ $self->attributes };
 	for my $attribute ( @{ $self->attributes } ) {
-		$code .= $attribute->generate_code($comments);
+		$code .= $attribute->generate_code($use_mouse, $comments);
 	}
 
 	# Generate subtypes
